@@ -1,5 +1,6 @@
 """API clients"""
 
+# flake8: noqa
 from .assets import AssetsService
 from .auth import AuthService
 from .bus import MessageBusService
@@ -10,17 +11,4 @@ from .facilities import FacilitiesService
 from .health import HealthService
 from .iot import IotDataService, IotService
 from .ngest import NgestService
-
-__all__ = [
-    "AssetsService",
-    "AuthService",
-    "MessageBusService",
-    "ContxtService",
-    "EmsService",
-    "EventsService",
-    "FacilitiesService",
-    "HealthService",
-    "IotService",
-    "IotDataService",
-    "NgestService",
-]
+from .sis import SisService
